package com.yiqi.order.mapper;

import java.util.List;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import org.apache.ibatis.annotations.Mapper;
import com.yiqi.order.domain.OrderClothItemCouponRelation;

/**
 * 洗衣订单衣服优惠情况Mapper接口
 *
 * @author xiaohei
 * @date 2023-11-07
 */
@Mapper
public interface OrderClothItemCouponRelationMapper extends BaseMapper<OrderClothItemCouponRelation> {
    /**
     * 查询洗衣订单衣服优惠情况
     *
     * @param id 洗衣订单衣服优惠情况主键
     * @return 洗衣订单衣服优惠情况
     */
    public OrderClothItemCouponRelation selectOrderClothItemCouponRelationById(Long id);

    /**
     * 查询洗衣订单衣服优惠情况列表
     *
     * @param orderClothItemCouponRelation 洗衣订单衣服优惠情况
     * @return 洗衣订单衣服优惠情况集合
     */
    public List<OrderClothItemCouponRelation> selectOrderClothItemCouponRelationList(OrderClothItemCouponRelation orderClothItemCouponRelation);

    /**
     * 新增洗衣订单衣服优惠情况
     *
     * @param orderClothItemCouponRelation 洗衣订单衣服优惠情况
     * @return 结果
     */
    public int insertOrderClothItemCouponRelation(OrderClothItemCouponRelation orderClothItemCouponRelation);

    /**
     * 修改洗衣订单衣服优惠情况
     *
     * @param orderClothItemCouponRelation 洗衣订单衣服优惠情况
     * @return 结果
     */
    public int updateOrderClothItemCouponRelation(OrderClothItemCouponRelation orderClothItemCouponRelation);

    /**
     * 删除洗衣订单衣服优惠情况
     *
     * @param id 洗衣订单衣服优惠情况主键
     * @return 结果
     */
    public int deleteOrderClothItemCouponRelationById(Long id);

    /**
     * 批量删除洗衣订单衣服优惠情况
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteOrderClothItemCouponRelationByIds(Long[] ids);
}
